<script lang="ts">
import { defineComponent, onUnmounted, reactive } from 'vue';

import { AppstoreOutlined, FieldTimeOutlined, LineChartOutlined, WarningOutlined, ThunderboltOutlined, CheckCircleOutlined } from '@ant-design/icons-vue';
import * as echarts from 'echarts';
import img from '#/assets/images/2t.png';
export default defineComponent({
  name: 'InjectionMoldingMachineDetail',
  components: {
    LineChartOutlined,
    WarningOutlined,
    AppstoreOutlined,
    CheckCircleOutlined,
    FieldTimeOutlined,
    ThunderboltOutlined
  },
  setup() {
    // 模拟数据
    const deviceInfo = reactive({
      deviceName: '立式注塑机',
      deviceType: '注塑机',
      deviceId: 'GPC2013C027',
      installDate: '2014-01-06',
      serviceLife: 15,
      status: '运行中',
      statusColor: '#52c41a',
      imageUrl: img // 添加设备图片路径
    });

    const healthData = reactive({
      overallHealth: 88,
      healthColor: '#faad14',
      predictedLife: 1500,
      riskLevel: '中风险',
      riskColor: '#faad14',
      injectionPressure: 120, // 注塑压力
      clampingForce: 80, // 锁模力
      moldTemperature: 45, // 模具温度
      screwSpeed: 150, // 螺杆转速
      meltTemperature: 220, // 熔融温度
      coolingTime: 25, // 冷却时间
      injectionCount: '495d 19h 44 ', // 注射次数
      clampingCount: 545636, // 合模次数
      productionCycle: 19, // 生产周期
      energyConsumption: 1500, // 能耗
      yieldRate: 98.5, // 良品率
      downtime: 120 // 出错停机时间
    });

    const maintenanceColumns = [
      {
        title: '维护类型',
        dataIndex: 'type',
        key: 'type'
      },
      {
        title: '维护内容',
        dataIndex: 'content',
        key: 'content'
      },
      {
        title: '建议时间',
        dataIndex: 'suggestedTime',
        key: 'suggestedTime'
      },
      {
        title: '紧急程度',
        dataIndex: 'urgency',
        key: 'urgency',
        slots: { customRender: 'urgency' }
      },
      {
        title: '操作',
        key: 'action',
        slots: { customRender: 'action' }
      }
    ];

    const maintenanceData = reactive([
      {
        key: '1',
        type: '例行保养',
        content: '检查液压油污染度',
        suggestedTime: '2024-07-15',
        urgency: '中等'
      },
      {
        key: '2',
        type: '故障预警',
        content: '主电机轴承磨损预警',
        suggestedTime: '2024-08-01',
        urgency: '高'
      },
      {
        key: '3',
        type: '冷却系统维护',
        content: '检查冷却水流量',
        suggestedTime: '2024-07-01',
        urgency: '低'
      }
    ]);

    const getUrgencyColor = (urgency: string) => {
      switch (urgency) {
        case '中等': {
          return 'orange';
        }
        case '低': {
          return 'green';
        }
        case '高': {
          return 'red';
        }
        default: {
          return 'default';
        }
      }
    };

    const sparePartColumns = [
      {
        title: '部件名称',
        dataIndex: 'name',
        key: 'name'
      },
      {
        title: '当前寿命',
        dataIndex: 'currentLife',
        key: 'currentLife',
        customRender: ({ text }: { text: number }) => `${text}小时`
      },
      {
        title: '预测剩余寿命',
        dataIndex: 'remainingLife',
        key: 'remainingLife',
        customRender: ({ text }: { text: number }) => `${text}小时`
      },
      {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
        slots: { customRender: 'status' }
      }
    ];

    const sparePartData = reactive([
      {
        key: '1',
        name: '液压泵',
        currentLife: 18_500,
        remainingLife: 1500,
        status: '预警'
      },
      {
        key: '2',
        name: '加热圈',
        currentLife: 12_000,
        remainingLife: 3000,
        status: '良好'
      },
      {
        key: '3',
        name: '螺杆料筒',
        currentLife: 25_000,
        remainingLife: 5000,
        status: '良好'
      }
    ]);

    const historyData = reactive([
      {
        id: '1',
        date: '2023-10-20',
        type: '例行保养',
        description: '更换液压油滤芯',
        color: 'green'
      },
      {
        id: '2',
        date: '2023-08-15',
        type: '故障维修',
        description: '注射单元卡滞，清理异物',
        color: 'red'
      },
      {
        id: '3',
        date: '2023-06-01',
        type: '年度保养',
        description: '全面检查设备运行状态',
        color: 'blue'
      }
    ]);

    const getStatusColor = (status: string) => {
      switch (status) {
        case '危险': {
          return '#f5222d';
        }
        case '良好': {
          return '#52c41a';
        }
        case '预警': {
          return '#faad14';
        }
        default: {
          return '#d9d9d9';
        }
      }
    };

    const handleMaintenance = (record: any) => {
      console.log('处理维护建议:', record);
      // 实际项目中这里会调用API处理维护建议
    };

    return {
      deviceInfo,
      healthData,
      maintenanceColumns,
      maintenanceData,
      sparePartColumns,
      sparePartData,
      historyData,
      getStatusColor,
      getUrgencyColor,
      handleMaintenance
    };
  },
  mounted() {
    // 初始化图表
    const initChart = (chartId: string, title: string, chartData: any[], unit: string, baseValue: number, fluctuation: number) => {
      const chart = echarts.init(document.getElementById(chartId));

      // 确保初始数据点足够显示一个完整的趋势
      if (chartData.length === 0) {
        const now = new Date();
        for (let i = 0; i < 60; i++) {
          // 生成60个点，代表5分钟的数据
          const time = new Date(now.getTime() - (59 - i) * 5000); // 每个点间隔5秒
          chartData.push({
            time: time.toLocaleTimeString(),
            value: (baseValue + Math.random() * fluctuation * 2 - fluctuation).toFixed(2)
          });
        }
      }

      const updateChart = () => {
        // 生成新的数据点
        const now = new Date();
        const time = `${now.getHours()}:${now.getMinutes()}:${now.getSeconds()}`;
        const newValue = (baseValue + Math.random() * fluctuation * 2 - fluctuation).toFixed(2);

        // 添加新数据点，最多保留60个点（5分钟数据）
        chartData.push({
          time,
          value: newValue
        });
        if (chartData.length > 60) {
          chartData.shift();
        }

        const option = {
          title: {
            text: title,
            left: 'center'
          },
          tooltip: {
            trigger: 'axis',
            formatter: (params) => {
              return `${params[0].axisValueLabel}<br/>${params[0].marker} ${params[0].seriesName}: ${params[0].data}${unit}`;
            }
          },
          grid: {
            left: '8%', // 增加左侧边距
            right: '5%',
            bottom: '10%',
            containLabel: true
          },
          xAxis: {
            type: 'category',
            data: chartData.map((item) => item.time)
          },
          yAxis: {
            type: 'value',
            axisLabel: {
              formatter: (value) => `${value}${unit}`
            }
          },
          series: [
            {
              data: chartData.map((item) => Number.parseFloat(item.value)),
              type: 'line',
              smooth: true,
              lineStyle: {
                width: 2,
                color: '#5470C6' // Default color
              },
              areaStyle: {
                opacity: 0.8,
                color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                  {
                    offset: 0,
                    color: 'rgba(84,112,198,0.3)'
                  },
                  {
                    offset: 1,
                    color: 'rgba(84,112,198,0)'
                  }
                ])
              }
            }
          ]
        };
        chart.setOption(option);
      };

      // 初始渲染
      updateChart();

      // 每5秒更新一次数据
      const intervalId = setInterval(updateChart, 5000);

      window.addEventListener('resize', () => {
        chart.resize();
      });
      onUnmounted(() => {
        clearInterval(intervalId);
      });
    };

    const hydraulicOilTemperatureData: any[] = [];
    const hydraulicOilPressureData: any[] = [];
    const mainMotorCurrentData: any[] = [];
    const screwSpeedData: any[] = [];
    const moldClampingForceData: any[] = [];
    const injectionPressureData: any[] = [];
    const injectionSpeedData: any[] = [];
    const barrelTemperatureData: any[] = [];
    const coolingWaterTemperatureData: any[] = [];
    const coolingWaterFlowData: any[] = [];
    const ejectorPositionData: any[] = [];
    const cycleTimeData: any[] = [];

    // initChart('hydraulicOilTemperatureChart', '液压油温', hydraulicOilTemperatureData, '°C', 50, 2);
    // initChart('hydraulicOilPressureChart', '液压油压', hydraulicOilPressureData, 'MPa', 150, 5);
    // initChart('mainMotorCurrentChart', '主电机电流', mainMotorCurrentData, 'A', 80, 3);
    initChart('screwSpeedChart', '螺杆转速', screwSpeedData, 'rpm', 100, 10);
    initChart('moldClampingForceChart', '锁模力', moldClampingForceData, 'kN', 1000, 50);
    initChart('injectionPressureChart', '注射压力', injectionPressureData, 'MPa', 1200, 80);
    initChart('injectionSpeedChart', '注射速度', injectionSpeedData, 'mm/s', 150, 10);
    initChart('barrelTemperatureChart', '料筒温度', barrelTemperatureData, '°C', 240, 3);
    initChart('coolingWaterTemperatureChart', '冷却水温度', coolingWaterTemperatureData, '°C', 25, 2);
    // initChart('coolingWaterFlowChart', '冷却水流量', coolingWaterFlowData, 'L/min', 30, 3);
    // initChart('ejectorPositionChart', '顶出位置', ejectorPositionData, 'mm', 50, 5);
    // initChart('cycleTimeChart', '循环时间', cycleTimeData, 's', 30, 2);
  }
});
</script>

<template>
  <div class="device-detail-container">
    <a-page-header :sub-title="deviceInfo.deviceName" title="注塑机预测性维护详情" @back="() => $router.go(-1)" />

    <a-row :gutter="16" class="mt-4">
      <!-- 设备图片和设备基本信息合并 -->
      <a-col :span="10">
        <a-card :style="{ height: '440px' }" class="mb-4" title="设备信息">
          <a-row :gutter="16">
            <a-col :span="12">
              <div class="device-image-container">
                <img :src="deviceInfo.imageUrl" alt="设备图片" class="device-image" />
              </div>
            </a-col>
            <a-col :span="12">
              <a-descriptions :column="1" bordered>
                <a-descriptions-item label="设备名称">{{ deviceInfo.deviceName }}</a-descriptions-item>
                <a-descriptions-item label="设备类型">{{ deviceInfo.deviceType }}</a-descriptions-item>
                <a-descriptions-item label="设备编号">{{ deviceInfo.deviceId }}</a-descriptions-item>
                <a-descriptions-item label="安装日期">{{ deviceInfo.installDate }}</a-descriptions-item>
                <a-descriptions-item label="使用年限">{{ deviceInfo.serviceLife }}年</a-descriptions-item>
                <a-descriptions-item label="当前状态">
                  <a-tag :color="deviceInfo.statusColor">{{ deviceInfo.status }}</a-tag>
                </a-descriptions-item>
              </a-descriptions>
            </a-col>
          </a-row>
        </a-card>
      </a-col>

      <!-- 设备健康状态与维护建议 -->
      <a-col :span="14">
        <a-card :style="{ height: '440px' }" class="mb-4" title="设备健康状态与维护建议">
          <a-row :gutter="16">
            <a-col :span="8">
              <a-statistic
                :precision="0"
                :value="healthData.overallHealth"
                :value-style="{ color: healthData.healthColor }"
                suffix="%"
                title="整体健康度"
              />
            </a-col>
            <a-col :span="8">
              <a-statistic :value="healthData.predictedLife" suffix="天" title="预测剩余寿命" />
            </a-col>
            <a-col :span="8">
              <a-statistic :value="healthData.riskLevel" :value-style="{ color: healthData.riskColor }" title="故障风险等级" />
            </a-col>
          </a-row>
          <div class="mt-4">
            <a-progress :percent="healthData.overallHealth" :show-info="false" :stroke-color="healthData.healthColor" />
          </div>
          <a-divider orientation="left">预测性维护建议</a-divider>
          <a-table :columns="maintenanceColumns" :data-source="maintenanceData" :pagination="false" size="small">
            <template #urgency="{ text }">
              <a-tag :color="getUrgencyColor(text)">{{ text }}</a-tag>
            </template>
            <template #action="{ record }">
              <a-button size="small" type="link" @click="handleMaintenance(record)">处理</a-button>
            </template>
          </a-table>
        </a-card>
      </a-col>
    </a-row>
    <a-col :span="24">
      <a-card class="mb-4" title="设备数据">
        <a-row :gutter="[16, 16]">
          <a-col :span="4">
            <a-statistic :value="healthData.injectionCount" suffix="min" title="总开机时间">
              <template #prefix>
                <LineChartOutlined />
              </template>
            </a-statistic>
          </a-col>
          <a-col :span="4">
            <a-statistic :value="healthData.clampingCount" suffix="次" title="总循环次数">
              <template #prefix>
                <LineChartOutlined />
              </template>
            </a-statistic>
          </a-col>
          <a-col :span="4">
            <a-statistic :value="healthData.productionCycle" suffix="s" title="生产周期">
              <template #prefix>
                <FieldTimeOutlined />
              </template>
            </a-statistic>
          </a-col>
          <a-col :span="4">
            <a-statistic :value="healthData.energyConsumption" suffix="kWh" title="能耗">
              <template #prefix>
                <ThunderboltOutlined />
              </template>
            </a-statistic>
          </a-col>
          <a-col :span="4">
            <a-statistic :value="healthData.yieldRate" suffix="%" title="良品率">
              <template #prefix>
                <CheckCircleOutlined />
              </template>
            </a-statistic>
          </a-col>
<!--          <a-col :span="4">-->
<!--            <a-statistic :value="healthData.downtime" suffix="s" title="出错停机时间">-->
<!--              <template #prefix>-->
<!--                <FieldTimeOutlined />-->
<!--              </template>-->
<!--            </a-statistic>-->
<!--          </a-col>-->
        </a-row>
      </a-card>
    </a-col>

    <!-- 实时数据趋势图 -->
    <a-card class="mb-4" title="实时数据趋势图">
<!--      <a-row :gutter="16">-->
<!--        <a-col :span="8">-->
<!--          <div id="hydraulicOilTemperatureChart" style="height: 300px"></div>-->
<!--        </a-col>-->
<!--        <a-col :span="8">-->
<!--          <div id="hydraulicOilPressureChart" style="height: 300px"></div>-->
<!--        </a-col>-->
<!--        <a-col :span="8">-->
<!--          <div id="mainMotorCurrentChart" style="height: 300px"></div>-->
<!--        </a-col>-->
<!--      </a-row>-->
      <a-row :gutter="16" class="mt-4">
        <a-col :span="8">
          <div id="screwSpeedChart" style="height: 300px"></div>
        </a-col>
        <a-col :span="8">
         <div id="barrelTemperatureChart" style="height: 300px"></div>
        </a-col>
        <a-col :span="8">
          <div id="injectionPressureChart" style="height: 300px"></div>
        </a-col>
      </a-row>
      <a-row :gutter="16" class="mt-4">
        <a-col :span="8">
          <div id="injectionSpeedChart" style="height: 300px"></div>
        </a-col>
        <a-col :span="8">
           <div id="moldClampingForceChart" style="height: 300px"></div>

        </a-col>
        <a-col :span="8">
          <div id="coolingWaterTemperatureChart" style="height: 300px"></div>
        </a-col>
      </a-row>
<!--      <a-row :gutter="16" class="mt-4">-->
<!--        <a-col :span="8">-->
<!--          <div id="coolingWaterFlowChart" style="height: 300px"></div>-->
<!--        </a-col>-->
<!--        <a-col :span="8">-->
<!--          <div id="ejectorPositionChart" style="height: 300px"></div>-->
<!--        </a-col>-->
<!--        <a-col :span="8">-->
<!--          <div id="cycleTimeChart" style="height: 300px"></div>-->
<!--        </a-col>-->
<!--      </a-row>-->
    </a-card>

    <a-row :gutter="16">
      <!-- 备件寿命预测 -->
      <a-col :span="12">
        <a-card class="mb-4" title="备件寿命预测">
          <a-table :columns="sparePartColumns" :data-source="sparePartData" :pagination="false" size="small">
            <template #status="{ text }">
              <a-tag :color="getStatusColor(text)">{{ text }}</a-tag>
            </template>
          </a-table>
        </a-card>
      </a-col>

      <!-- 历史维护记录 -->
      <a-col :span="12">
        <a-card class="mb-4" title="历史维护记录">
          <a-timeline>
            <a-timeline-item v-for="item in historyData" :key="item.id" :color="item.color">
              <p>{{ item.date }} - {{ item.type }}：{{ item.description }}</p>
            </a-timeline-item>
          </a-timeline>
        </a-card>
      </a-col>
    </a-row>
  </div>
</template>

<style scoped>
.device-detail-container {
  padding: 20px;
  background-color: #f0f2f5;
}

.device-image-container {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 330px;
}

.device-image {
  max-width: 100%;
  max-height: 100%;
  object-fit: contain;
}

.mb-4 {
  margin-bottom: 16px;
}

.mt-4 {
  margin-top: 16px;
}
</style>
